if (FALSE) {
### Downloading the minimum air temperature and maximum air temperature based on Brazil states.
see_brazil_states()
img <- download_terraclimate(
dir_out = "C:/teste/tmin/state", variable = "tmin",
years = c(2018:2019),
region = "brazil",
sub_region = 13
)
### Downloading the minimum air temperature and maximum air temperature based on Brazil states.
see_brazil_biomes()
img <- download_terraclimate(
dir_out = "C:/teste/tmin/biome", variable = "tmin",
years = c(2018:2019),
region = "biomes_brazil",
sub_region = 6
)
}
Run the code above in your browser using DataLab