Learn R Programming

cropZoning (version 1.0.3)

see_brazil_biomes: Function to see the Brazilian biomes available in cropZoning package and how we can use it in the loadROI function

Description

This fuction will show the biomes available in the package and how we can call each biome polygon.

Usage

see_brazil_biomes()

Arguments

Value

Returns a character strings listing the biomes available to run the cropZoning package.

Examples

Run this code
if (FALSE) {

see_brazil_biomes()
}

Run the code above in your browser using DataLab