Learn R Programming

cropZoning (version 1.0.3)

see_brazil_states: Function to see the Brazilian states available in cropZoning package and how we can use it in the loadROI function

Description

This function will show the Brazilian state available in the package and how we can call each state polygon.

Usage

see_brazil_states()

Arguments

Value

Returns a character strings listing the the Brazilian states available to run the cropZoning package.

Examples

Run this code
if (FALSE) {

see_brazil_states()
}

Run the code above in your browser using DataLab