Learn R Programming

cropZoning (version 1.0.3)

tmax_calibration: Calibration of maximum air temperature from TerraClimate

Description

This function will calibrate the maximum air temperature from TerraClimate dataset based in the relationship with observed weather stations data.The values of slope and intercept informed in example correspond a calibration performed between 'Terraclimate' images and INMET automatic weather stations realized for all the brazilian territory.

Usage

tmax_calibration(slope, intercept, tmax_stack)

Value

Returns a SpatRaster object of calibrated maximum air temperature.

Arguments

slope

the slope of the linear regression (numeric)

intercept

the intercept of the linear regression (numeric)

tmax_stack

stack of maximum air temperature

Examples

Run this code
if (FALSE) {

tmax_cal<- tmax_calibration(slope = 0.874787, intercept = 4.612894 , tmax_stack = tmax);
}

Run the code above in your browser using DataLab