Learn R Programming

cropZoning (version 1.0.3)

tmin_calibration: Calibration of minimum air temperature from TerraClimate

Description

This function will calibrate the minimum air temperature from TerraClimate dataset based in the relationship with observed weather stations data. The values of slope and intercept informed in example correspond a calibration performed between 'Terraclimate' images and INMET automatic weather stations realized for all the brazilian territory.

Usage

tmin_calibration(slope, intercept, tmin_stack)

Value

Returns a SpatRaster of calibrated minimum air temperature.

Arguments

slope

the slope of the linear regression (numeric)

intercept

the intercept of the linear regression (numeric)

tmin_stack

stack of maximum air temperature

Examples

Run this code
if (FALSE) {
tmin_cal<- tmin_calibrated(slope = 0.830652, intercept = 4.187840, tmin_stack = tmin);
}

Run the code above in your browser using DataLab