powered by
This fuction will show the biomes available in the package and how we can call each biome polygon.
see_brazil_biomes()
Returns a character strings listing the biomes available to run the cropZoning package.
if (FALSE) { see_brazil_biomes() }
Run the code above in your browser using DataLab