tmin_calibration: Calibration of minimum air temperature from TerraClimate
Description
This function will calibrate the minimum air temperature from TerraClimate dataset based in the relationship with observed weather stations data. The values of slope and intercept informed in example correspond a calibration performed between 'Terraclimate' images and INMET automatic weather stations realized for all the brazilian territory.
Usage
tmin_calibration(slope, intercept, tmin_stack)
Value
Returns a SpatRaster of calibrated minimum air temperature.